--TEST--
PEAR Bug #12310
--FILE--
<?php

require dirname(__FILE__) . '/../PDF.php';

class MyPDF extends File_PDF
{
    function header()
    {
        global $title;

        $this->setFont('Arial', 'B', 15);
        $w = $this->getStringWidth($title) + 6;
        $this->setX((210 - $w) / 2);
        $this->setDrawColor('rgb', 0/255, 80/255, 180/255);
        $this->setFillColor('rgb', 230/255, 230/255, 0/255);
        $this->setTextColor('rgb', 220/255, 50/255, 50/255);
        $this->setLineWidth(1);
        $this->cell($w, 9, $title, 1, 1, 'C', 1);
        $this->newLine(10);
    }

    function footer()
    {
        $this->setY(-15);
        $this->setFont('Arial', 'I', 8);
        $this->setTextColor('gray', 128/255);
        $this->cell(0, 10, 'Page ' . $this->getPageNo(), 0, 0, 'C');
    }

    function chapterTitle($num, $label)
    {
        $this->setFont('Arial', '', 12);
        $this->setFillColor('rgb', 200/255, 220/255, 255/255);
        $this->cell(0, 6, "Chapter $num : $label", 0, 1, 'L', 1);
        $this->newLine(4);
    }

    function chapterBody($file)
    {
        $this->setFont('Times', '', 12);
        $this->multiCell(0, 5, $file);
        $this->newLine();
        $this->setFont('', 'I');
        $this->cell(0, 5, '(end of extract)');
    }

    function printChapter($num, $title, $file)
    {
        $this->addPage();
        $this->chapterTitle($num, $title);
        $this->chapterBody($file);
    }

}

$pdf = MyPDF::factory(array('orientation' => 'P',
                            'unit' => 'mm',
                            'format' => 'A4'),
                      'MyPDF');
$pdf->setCompression(false);
$title = '20000 Leagues Under the Seas';
$pdf->setInfo('title', $title);
$pdf->setInfo('author', 'Jules Verne');
$pdf->printChapter(1, 'A RUNAWAY REEF', 'abcABC');
$pdf->printChapter(2, 'THE PROS AND CONS', 'defDEF');
echo $pdf->getOutput();

?>
--EXPECTF--
%PDF-1.3
3 0 obj
<</Type /Page
/Parent 1 0 R
/Resources 2 0 R
/Contents 4 0 R>>
endobj
4 0 obj
<</Length 541>>
stream
2 J
0.57 w
BT /F1 15.00 Tf ET
0.000 0.314 0.706 RG
0.902 0.902 0.000 rg
2.83 w
179.09 813.54 237.10 -25.51 re B q 0.863 0.196 0.196 rg BT 187.59 796.28 Td (20000 Leagues Under the Seas) Tj ET Q
0.57 w
0 G
0 g
BT /F2 12.00 Tf ET
0.784 0.863 1.000 rg
28.35 759.68 538.58 -17.01 re f q 0 g BT 31.19 747.58 Td (Chapter 1 : A RUNAWAY REEF) Tj ET Q
BT /F3 12.00 Tf ET
q 0 g BT 31.19 720.65 Td (abcABC) Tj ET Q
BT /F4 12.00 Tf ET
q 0 g BT 31.19 692.30 Td (\(end of extract\)) Tj ET Q
BT /F5 8.00 Tf ET
q 0.502 g BT 284.96 25.95 Td (Page 1) Tj ET Q

endstream
endobj
5 0 obj
<</Type /Page
/Parent 1 0 R
/Resources 2 0 R
/Contents 6 0 R>>
endobj
6 0 obj
<</Length 600>>
stream
2 J
0.57 w
0.784 0.863 1.000 rg
BT /F1 15.00 Tf ET
0.000 0.314 0.706 RG
0.902 0.902 0.000 rg
2.83 w
179.09 813.54 237.10 -25.51 re B q 0.863 0.196 0.196 rg BT 187.59 796.28 Td (20000 Leagues Under the Seas) Tj ET Q
0.57 w
BT /F5 8.00 Tf ET
0 G
0.784 0.863 1.000 rg
BT /F2 12.00 Tf ET
0.784 0.863 1.000 rg
28.35 759.68 538.58 -17.01 re f q 0 g BT 31.19 747.58 Td (Chapter 2 : THE PROS AND CONS) Tj ET Q
BT /F3 12.00 Tf ET
q 0 g BT 31.19 720.65 Td (defDEF) Tj ET Q
BT /F4 12.00 Tf ET
q 0 g BT 31.19 692.30 Td (\(end of extract\)) Tj ET Q
BT /F5 8.00 Tf ET
q 0.502 g BT 284.96 25.95 Td (Page 2) Tj ET Q

endstream
endobj
1 0 obj
<</Type /Pages
/Kids [3 0 R 5 0 R ]
/Count 2
/MediaBox [0 0 595.28 841.89]
>>
endobj
7 0 obj
<</Type /Font
/BaseFont /Helvetica-Bold
/Subtype /Type1
/Encoding /WinAnsiEncoding
>>
endobj
8 0 obj
<</Type /Font
/BaseFont /Helvetica
/Subtype /Type1
/Encoding /WinAnsiEncoding
>>
endobj
9 0 obj
<</Type /Font
/BaseFont /Times-Roman
/Subtype /Type1
/Encoding /WinAnsiEncoding
>>
endobj
10 0 obj
<</Type /Font
/BaseFont /Times-Italic
/Subtype /Type1
/Encoding /WinAnsiEncoding
>>
endobj
11 0 obj
<</Type /Font
/BaseFont /Helvetica-Oblique
/Subtype /Type1
/Encoding /WinAnsiEncoding
>>
endobj
2 0 obj
<</ProcSet [/PDF /Text /ImageB /ImageC /ImageI]
/Font <<
/F1 7 0 R
/F2 8 0 R
/F3 9 0 R
/F4 10 0 R
/F5 11 0 R
>>
>>
endobj
12 0 obj
<<
/Producer (Horde PDF)
/Title (20000 Leagues Under the Seas)
/Author (Jules Verne)
/CreationDate (D:%d)
>>
endobj
13 0 obj
<<
/Type /Catalog
/Pages 1 0 R
/OpenAction [3 0 R /FitH null]
/PageLayout /OneColumn
>>
endobj
xref
0 14
0000000000 65535 f 
0000001404 00000 n 
0000001997 00000 n 
0000000009 00000 n 
0000000087 00000 n 
0000000677 00000 n 
0000000755 00000 n 
0000001497 00000 n 
0000001598 00000 n 
0000001694 00000 n 
0000001792 00000 n 
0000001892 00000 n 
0000002127 00000 n 
0000002264 00000 n 
trailer
<<
/Size 14
/Root 13 0 R
/Info 12 0 R
>>
startxref
2368
%%EOF
